import React from 'react'
import { Route, RouteProps, useLocation, useHistory } from 'react-router-dom'

import { setCookie } from 'utils'
import { useUserContext } from 'contexts'

interface IProtectedRoute extends RouteProps {
  children: React.ReactNode
}

function ProtectedRoute({ children, ...rest }: IProtectedRoute) {
  // Simple protected route component
  const { user } = useUserContext()

  if ( !user.auth ) {
    const location = useLocation()
    const history = useHistory()
    setCookie('redirect', location.pathname)
    history.push('/')
  }

  return (
    <Route {...rest}>
      {children}
    </Route>
  )
}

export default ProtectedRoute
