import { FetchedRole, Guest } from 'interfaces'
import { useEffect, useState } from 'react'
import { parseRole, parseIdentity } from 'utils'

const useGuest = (pid: string) => {
  const [guestInfo, setGuest] = useState<Guest>({
    pid: '',
    first: '',
    last: '',
    email: '',
    fnr: null,
    passport: null,
    mobile: '',
    active: false,
    registered: false,
    verified: false,
    roles: [],
  })

  const getPerson = async (id: string) => {
    try {
      const response = await fetch(`/api/ui/v1/person/${id}`)
      const rjson = await response.json()

      if (response.ok) {
        setGuest({
          pid: rjson.pid,
          first: rjson.first,
          last: rjson.last,
          email: rjson.email,
          mobile: rjson.mobile,
          fnr: parseIdentity(rjson.fnr),
          passport: parseIdentity(rjson.passport),
          active: rjson.active,
          registered: rjson.registered,
          verified: rjson.verified,
          roles: rjson.roles.map((role: FetchedRole) => parseRole(role)),
        })
      }
    } catch (error) {
      console.error(error)
    }
  }
  const reloadGuestInfo = () => {
    getPerson(pid)
  }
  useEffect(() => {
    getPerson(pid)
  }, [])

  return { guestInfo, reloadGuestInfo }
}

export default useGuest
