from rest_framework.authentication import SessionAuthentication, BasicAuthentication
from rest_framework.permissions import IsAuthenticated
from rest_framework.viewsets import GenericViewSet
from rest_framework import mixins
from rest_framework.exceptions import MethodNotAllowed
from greg.models import Identity
from greg.permissions import IsSponsor
from gregui.api.serializers.identity import IdentitySerializer
from gregui.models import GregUserProfile


class IdentityViewSet(
    mixins.RetrieveModelMixin,
    mixins.UpdateModelMixin,
    GenericViewSet,
):
    """
    Fetch or update identity info for any guest as long as you are a sponsor.

    This is required for when a host(sponsor) needs to verify the identity of a guest
    so that they are considered "active".

    Limited to GET and PATCH so that we can only update or get a single identity at a
    time.
    """

    queryset = Identity.objects.all()
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated, IsSponsor]
    serializer_class = IdentitySerializer
    http_method_names = ["get", "patch"]
